%% ===========================================================================
% Copyright (C):
%       1998-2000 by Telia Research AB, Lulea, Sweden
%       2001-2003 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% 
% Description   : Main VDSL simulation program with
%                 a graphical user interface. (GUI)
%
% File          : uiMain.m
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: uiMain.m,v 3.2 2003/03/07 16:41:33 tono Exp $
%% ===========================================================================

%% ===========================================================================
% Change History
%      1998-11-12 (ToNo) Created
%      1999-03-25 (ToNo) Restructured the source (moved into subdir xdslcomm)
%      1999-10-03 (DaB)  Rewritten for new ex and gui struct
%      2000-04-05 (UvAn) New return value from etsi_tfplanHAM
%% ===========================================================================
global ex;
global gui;
global simures;

greetings;

%% ===========================================================================
% Setup default gui struct
gui            = setupGUI;
gui.ttlist     = fsan_loopsVDSL(gui.ttlist);

% Set up a specific start experiment (to have something for gui)
gui.scenario   = 'FSAN scenario FTTEx #1';         % Scenario to run
gui.vdslDuplex = 'VDSL-test';                      % Duplex method for VDSL

% Set up default experiment structures
ex.param       = setupParam(gui.vdslDuplex);       % Parameters
[ex.tfplist, ex.param.HAMBandName] = ...
	etsi_tfplanHAM([]);                        % Need a HAM band definition
ex.tfplist     = fsan_modelsMISC(ex.tfplist);      % Get plans for alien noise
ex.tfplist     = etsi_noisesVDSL(ex.tfplist);	   % Get VDSL noise models
ex.tfplist     = special_modelsVDSL(ex.tfplist);   % Get test VDSL plans
ex.lclist      = setupLClist;
ex.clist       = etsi_cablesVDSL([]);              % Get ETSI (& ANSI) cables;
ex.tt          = getList(gui.ttlist,gui.scenario);

gui.PBO.maxlen = getMaxVDSLlength(ex.tt.topology,ex.tt.traffic);

%% ===========================================================================
% If available, include some user definitions
fid=fopen('userDefinitions.m','r');
if fid ~= -1,
    fclose(fid);
    userDefinitions;
end;

%% ===========================================================================
% Show setup and run from there
uiSetup;

