function ttlist = UserLoopsSDSL(ttlist);
%% ===========================================================================
% Copyright (C) 2000-2003 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                     All rights reserved. 
% Description   : Define some loops for SDSL tests
%
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Gernot Schmid (gernot.schmid@arcs.ac.at) 
%
% CVS:       $Id: UserLoopsSDSL.m,v 3.3 2003/11/03 15:45:41 tono Exp $
%% ===========================================================================

%% ===========================================================================
% Change History
%      2000-10-25   (GS) Created 
%      2002-03-18 (ToNo) Renamed the SDSL cables
%      2003-11-03 (ToNo) Lists now use cell arrays for both Octave and Matlab
%% ===========================================================================


% Example for Reach calculation (ExSDSLreach.m)
% Length definitions in topology struct are ignored by SDSLreach.m !!
tt.name= 'SDSL-Scenario 0';             
tt.topology={...
    {0,  '', 'CO', ''},... 
    {1000,  'ETSI-SDSL-PE04',   'NT1',  '-> 1000 m'}};
tt.traffic={...
   {1, 2, 'SDSL-sym-1024', 20},...
   {1, 2, 'ADSL',          20},...
   {1, 2, 'SDSL-sym-2048', 20},...
   {1, 2, 'ISDN-2B1Q',     10}};
ttlist=insertList(ttlist,tt);

% Example for Max. Bitrate Calculation (ExSDSLmargin.m)
% Investigated Service must be indicated by symbolic name without bitrate value
tt.name= 'SDSL-Scenario 1';       
tt.topology={...
    {0 , '', 'CO', ''},...
    {5000,  'ETSI-SDSL-PE08', 'NT1',  '-> 5000 m'},...
    {3500,  'ETSI-SDSL-PE06', 'NT2',  '-> 3500 m'}};
tt.traffic={...
   {1, 2, 'SDSL-sym',      20},...
   {1, 2, 'ADSL',          20},...
   {1, 3, 'SDSL-sym-2048', 20},...
   {1, 3, 'ISDN-2B1Q',     10},...
   {1, 3, 'ADSL',         20}};
ttlist=insertList(ttlist,tt);


% Example for Margin-Calculation (ExSDSLmargin.m)  With bridge taps
tt.name= 'SDSL-Scenario 2';           
tt.topology={...
   {0,   '',    'CO',   '',            0, '' ,    '',   ''},...
   {1000, 'ETSI-SDSL-PE08', 'NT1',   '-> 1000 m',  400, 'ETSI-SDSL-PE04', 'BT', '500m (ETSI-SDSL-PE04)'},... 
   {1300, 'ETSI-SDSL-PE04', '',    	'-> 1300 m',  300, 'ETSI-SDSL-PE04', 'BT', '500m (ETSI-SDSL-PE04)'},...
   {2000, 'ETSI-SDSL-PE04', 'NT2',   '-> 2000 m',    0, '', 	 '',   ''}};
tt.traffic={...
   {1, 2, 'SDSL-asym-2048', 30},...
   {1, 2, 'ADSL',           20},...
   {1, 4, 'SDSL-sym-512',   20},...
   {1, 4, 'ISDN-2B1Q',      20}};   
ttlist=insertList(ttlist,tt);
