function y = sinc(x)
%SINC   The function SIN(PI*X)/(PI*X).
%
%   SINC(X) returns the SIN(PI*X)/(PI*X) function which is defined as
%
%      1                 if x = 0
%      sin(pi*x)/(pi*x)  if 0 < |x| < infinity
%      0                 if x = infinity
%
%   See also SIN.

%   Author:      Peter J. Acklam
%   Time-stamp:  2003-10-20 08:44:58 +0200
%   E-mail:      pjacklam@online.no
%   URL:         http://home.online.no/~pjacklam

   % check number of input arguments
   error(nargchk(1, 1, nargin));

   y = ones(size(x));           % initialize output
   i = x ~= 0;                  % find non-zero elements
   t = pi * x(i);               % precompute PI*X
   y(i) = sin(t) ./ t;          % compute SIN(PI*X)/(PI*X)
   y(isinf(x)) = 0;             % 0 not NaN when X = +/-Inf
