% The xDSL simulation tool - The xDSL definitions
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functions to set up experiments
%
%  ETSI_VDSL_defs       Set up "everything" for an ETSI VDSL experiment
%  ANSI_VDSL_defs       Set up "everything" for an ANSI VDSL experiment
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functions for defining cables
%
%   etsi_cablesADSL     Define cables used in ETSI ASDL 
%   etsi_cablesSDSL     Define cables used in ETSI SSDL 
%   etsi_cablesVDSL     Define cables used in ETSI VSDL (and ANSI)
%   itu_cablesADSL      Define cables used in ITU ASDL 
%   etsi_cablesADSL_extr Define some other cables models used in ETSI ASDL 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functions for defining loops
%
%   ansi_loopsVDSL      Defines ANSI VDSL loops
%   etsi_loopsADSL      Defines ETSI ADSL loops
%   etsi_loopsSDSL      Defines ETSI SDSL loops
%   etsi_loopsVDSL      Defines ETSI VDSL loops
%   fsan_loopsVDSL      Defines FSAN VDSL loops
%   etsi_loopsSDSLdeflen.m  Defines default values for ETSI SDSL testloops
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functions for defining noise
%
%   ansi_noisesVDSL     Defines ANSI VDSL noise tfplans
%   etsi_noisesADSL     Defines ETSI ADSL noise tfplans
%   etsi_noisesSDSL     Defines ETSI SDSL noise tfplans
%   etsi_noisesVDSL     Defines ETSI VDSL noise tfplans
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functions for defining tfplans
%
%   ansi_tfplanHAM      Define ANSI HAM band tfpplan
%   etsi_tfplanHAM      Define ETSI HAM band tfpplan
%   itu_tfplanHAM       Define ITU HAM band tfpplan
%
%   etsi_tfplansVDSL    Define ETSI VDSL tfpplans
%   etsi_tfplansSDSL    Define ETSI SDSL tfpplans
%   etsi_tfplansADSL    Define ETSI ADSL tfpplans
%   special_modelsVDSL  Define special VDSL tfpplans
%   fsan_modelsMISC     Define standard "alien" tfpplans
%   itu_modelsPNT       Define ITU-T PNT model
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functions for defining linecode specifics
%
%   etsi_lcdefsVDSL     Set up lc models for ETSI VDSL
%   etsi_lcdefsSDSL     Set up lc models for ETSI SDSL
%   etsi_lcdefsADSL     Set up lc models for ETSI ADSL
%   lcDefADSLDMT        Define lc model for ADSL DMT
%   lcDefVDSLDMT        Define lc model for VDSL DMT
%   lcDefVDSLSCM        Define lc model for VDSL SCM
%   lcPrintDMT          Print DMT lc model
%   lcPrintSCM          Print SCM lc model
%   lcPrintSDSL         Print SDSL lc model
%   lcPrintTheo         Print Theo lc model
%   ETSI_SDSL_traffic2lctf Help routine to set up suitable SDSL lcdefs
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Functions for defining PSD masks
%
%   etsi_masksVDSL      Defines the PSD masks for ETSI VDSL
%   etsi_modelsVDSL_SCM Sets up the SCM PSDs according to ETSI VDSL part 2
%   modelPSD_HDSL       Defines a function that models HDSL PSD
%   modelPSD_ISDN_PRA   Defines a function that models ISDN PRA PSD
%   modelPSD_T1         Defines a function that models T1 PSD
%   modelPSD_SDSL_sym   Defines a function that models symmetrical ADSL
%   modelPSD_SDSL_asym  Defines a function that models asymmetrical ADSL
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Misc
%  Content  		This file
%
%% ===========================================================================

%% ===========================================================================
% Copyright (C):
%       2000-2003 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Description   : The contents of the xdsldefs directory
%
% File          : Content.m
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: Contents.m,v 3.2 2003/03/07 16:51:47 tono Exp $
%% ===========================================================================
% Change History
%      2000-09-17 (ToNo) Created
%      2002-08-23 (ToNo) Updated after "the big rename"
%% ===========================================================================
