%% ===========================================================================
% Copyright (C) 2000 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                     All rights reserved. 
% ETSI_SDSL_traffic2lctf : Adds linecodes and tfplans etc for all SDSL
%                          services in the considered traffic scenario to
%                          lclist, tfplist, and xDSLlist.
%
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Gernot Schmid (gernot.schmid@arcs.ac.at) 
%
% CVS:       $Id: ETSI_SDSL_traffic2lctf.m,v 3.1 2003/11/03 12:33:22 tono Exp $
%% ===========================================================================

%% ===========================================================================
% Change History
%      2000-10-05   (GS) Created 
%      2000-11-08 (ToNo) Made this into a definition file (not a function)
%      2001-10-18 (ToNo) Ported to Octave
%      2003-11-03 (ToNo) Lists now use cell arrays for both Octave and Matlab
%% ===========================================================================
global ex;

traffic = ex.tt.traffic;

% Find the bitrate of the considered SDSL service from its name in
% the traffic struct and create a corresponding linecode and tfplan
% and then add information to the various lists

n=length(traffic);
for i=1:n
   lcname=traffic{i}{3};
   if length(lcname)>4
    switch lcname(1:6) 
      case 'SDSL-s'
           tmp_lc=getList(ex.lclist,'SDSL-sym');
           tmp_lc.param.pam.brate.rate = 1e3*str2num(lcname(10:length(lcname)));
           fsym=(tmp_lc.param.pam.brate.rate+tmp_lc.param.pam.brate.ohead)/...
                tmp_lc.param.pam.bpsym;
           tmp_lc.name=lcname;
           ex.lclist=insertList(ex.lclist,tmp_lc);
           tfplan=getList(ex.tfplist,'SDSL-sym');
           tfplan.PSD.active.upstream   = [1 2*fsym];  
           tfplan.PSD.active.downstream = [1 2*fsym];
           tfplan.name=lcname;
           tfplan.lcname=lcname;
           ex.tfplist=insertList(ex.tfplist,tfplan);
           xDSL.name=lcname;   
           xDSL.used=lcname;    
           ex.param.xDSLlist=insertList(ex.param.xDSLlist,xDSL);
            
      case 'SDSL-a'
           tmp_lc=getList(ex.lclist,'SDSL-asym');
           tmp_lc.param.pam.brate.rate = 1e3*str2num(lcname(11:length(lcname)));
           fsym=(tmp_lc.param.pam.brate.rate+tmp_lc.param.pam.brate.ohead)/...
                 tmp_lc.param.pam.bpsym;
           tmp_lc.name=lcname;
           ex.lclist=insertList(ex.lclist,tmp_lc);
           tfplan=getList(ex.tfplist,'SDSL-asym');
           tfplan.PSD.active.upstream   = [1 2*fsym];  
           tfplan.PSD.active.downstream = [1 2*fsym];
           tfplan.name=lcname;
           tfplan.lcname=lcname;
           ex.tfplist=insertList(ex.tfplist,tfplan);
           xDSL.name=lcname;   
           xDSL.used=lcname;    
           ex.param.xDSLlist=insertList(ex.param.xDSLlist,xDSL);
  
      otherwise
      end
    end
end

