function ttlist = ansi_loopsVDSL(ttlist);
%% ===========================================================================
%ansi_loopsVDSL - Add the ansi loops to the ttlist
%
% Example(s):
%   gui.ttlist = ansi_loopsVDSL(gui.ttlist);
%   tt=getList(gui.ttlist,'ANSI VDSL loop1 short (ANSI_TP1)'); 
%   % Sets up tt to test the ANSI VDSL loop1.
%
% Reference:
%   T1E1.4 VDSL Editor, "Very-high-speed Digital Subscriber Lines - 
%   System Requirements", VDSL SR:08-043R6, November 30, 1998
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1999-2000 by Telia Research AB, Lulea, Sweden;                
%       2001-2003 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: ansi_loopsVDSL.m,v 3.3 2003/11/03 15:45:08 tono Exp $
%% ===========================================================================
% Change History
%      1999-08-13 (DaB)  Created
%      1999-10-04 (DaB)  Removed dm field
%      1999-10-25 (ToNo) Reorganized things into etsi,ansi,itu,fsan definitions
%      2000-03-14 (ToNo) Renamed cable models to include 'ANSI_'
%      2002-07-24 (ToNo) Port to octave
%      2003-11-03 (ToNo) Lists now use cell arrays for both Octave and Matlab
%% ===========================================================================

%% ===========================================================================
% Scenario definitions: Topology and traffic pattern

% -- Loop1 ANSI_TP1 cable --
% --------------------------
tt.name= 'ANSI VDSL loop1 short (ANSI_TP1)';             % T1E1.4 Loops
tt.topology={...
    {0,  '', 'CO', ''}, ...
    {1000*0.3048,  'ANSI_TP1', 'NT1', '1000 ft (305m) ANSI_TP1->'}};
tt.traffic={...
    {1, 2, 'VDSL', 25}};
ttlist=insertList(ttlist,tt);
% ttlist(1)=tt;

tt.name= 'ANSI VDSL loop1 medium (ANSI_TP1)';             % T1E1.4 Loops
tt.topology={...
    {0,  '', 'CO', ''},...
    {3000*0.3048,   'ANSI_TP1', 'NT1', '3000 ft (914 m) ANSI_TP1->'}};
tt.traffic={...
    {1, 2, 'VDSL', 25}};
ttlist=insertList(ttlist,tt);

tt.name= 'ANSI VDSL loop1 long (ANSI_TP1)';             % T1E1.4 Loops
tt.topology={...
    {0,  '', 'CO', ''},...
    {4500*0.3048,   'ANSI_TP1', 'NT1', '4500 ft (1.37 km) ANSI_TP1->'}};
tt.traffic={...
    {1, 2, 'VDSL', 25}};
ttlist=insertList(ttlist,tt);

% -- ANSI VDSL loop1 ANSI_TP2 cable ----
% ---------------------------------
tt.name= 'ANSI VDSL loop1 short (ANSI_TP2)';             % T1E1.4 Loops
tt.topology={...
    {0 , '', 'CO', ''},...
    {1500*0.3048,   'ANSI_TP2', 'NT1', '1500 ft (457 m) ANSI_TP2->'}};
tt.traffic={...
    {1, 2 ,'VDSL', 25}};
ttlist=insertList(ttlist,tt);

tt.name= 'ANSI VDSL loop1 medium (ANSI_TP2)';             % T1E1.4 Loops
tt.topology={...
    {0,  '', 'CO', ''},...
    {3000*0.3048,   'ANSI_TP2', 'NT1', '3000 ft (914 m) ANSI_TP2->'}};
tt.traffic={...
    {1, 2, 'VDSL', 25}};
ttlist=insertList(ttlist,tt);

tt.name= 'ANSI VDSL loop1 long (ANSI_TP2)';             % T1E1.4 Loops
tt.topology={...
    {0 , '', 'CO', ''},...
    {4500*0.3048,   'ANSI_TP2', 'NT1', '4500 ft (1.37 km) ANSI_TP2->'}};
tt.traffic={...
    {1, 2, 'VDSL', 25}};
ttlist=insertList(ttlist,tt);

% -- ANSI VDSL loop 2 -------------
% ---------------------------------
tt.name= 'ANSI VDSL loop2 short';             % T1E1.4 Loops
tt.topology={...
    {0,  '', 'CO', ''},...
    {1500*0.3048 ,  'ANSI_TP2', 'NT1', '1500 ft (457 m) ANSI_TP2->'},...
    {250*0.3048,   'ANSI_FP', 'NT1', '250 ft (76.2 m) ANSI_FP->'}};
tt.traffic={...
    {1, 3 ,'VDSL', 25}};
ttlist=insertList(ttlist,tt);

tt.name= 'ANSI VDSL loop2 medium';             % T1E1.4 Loops
tt.topology={...
    {0,  '', 'CO', ''},...
    {3000*0.3048 ,  'ANSI_TP2', 'NT1', '3000 ft (914 m) ANSI_TP2->'},...
    {250*0.3048,   'ANSI_FP', 'NT1', '250 ft (76.2 m) ANSI_FP->'}};
tt.traffic={...
    {1, 3, 'VDSL', 25}};
ttlist=insertList(ttlist,tt);
    
tt.name= 'ANSI VDSL loop2 long';             % T1E1.4 Loops
tt.topology={...
    {0,  '', 'CO', ''},...
    {4500*0.3048,   'ANSI_TP2', 'NT1', '4500 ft (1.37 km) ANSI_TP2->'},...
    {250*0.3048,   'ANSI_FP', 'NT1', '250 ft (76.2 m) ANSI_FP->'}};
tt.traffic={...
    {1, 3, 'VDSL', 25}};
ttlist=insertList(ttlist,tt);



%-- ANSI VDSL Loops 3 ----------
%-------------------------------
tt.name= 'ANSI VDSL loop3 short';             % T1E1.4 Loops
tt.topology={...
    {0,  '', 'CO', ''},...
    {1500*0.3048,   'ANSI_TP2', 'NT1', '1500 ft (457 m) ANSI_TP2->'},...
    {250*0.3048,   'ANSI_TP3', 'NT1', '250 ft (76.2 m) ANSI_TP3->'}};
 tt.traffic={...
    {1, 3, 'VDSL', 25}};
ttlist=insertList(ttlist,tt);

tt.name= 'ANSI VDSL loop3 medium';             % T1E1.4 Loops
tt.topology={...
    {0,  '', 'CO', ''},...
    {3000*0.3048,   'ANSI_TP2', 'NT1', '3000 ft (914 m) ANSI_TP2->'},...
    {250*0.3048,   'ANSI_TP3', 'NT1', '250 ft (76.2 m) ANSI_TP3->'}};
tt.traffic={...
    {1, 3, 'VDSL', 25}};
ttlist=insertList(ttlist,tt);
    
tt.name= 'ANSI VDSL loop3 long';             % T1E1.4 Loops
tt.topology={...
    {0,  '', 'CO', ''},...
    {4500*0.3048,   'ANSI_TP2', 'NT1', '4500 ft (1.37 km) ANSI_TP2->'},...
    {250*0.3048,   'ANSI_TP3', 'NT1', '250 ft (76.2 m) ANSI_TP3->'}};
tt.traffic={...
    {1, 3 ,'VDSL', 25}};
ttlist=insertList(ttlist,tt);



%-- ANSI VDSL loop 4 ----------------
% -----------------------------------
tt.name= 'ANSI VDSL loop4 short';             % T1E1.4 Loops
tt.topology={...
    {0,  '', 'CO', '', 0, '', '', ''},...
    {1000*0.3048,   'ANSI_TP1', 'Node', '1000 ft (305 m) ANSI_TP1->', 300*0.3048,   'ANSI_TP2', 'BT', '300 ft (91 m) ANSI_TP2->'},...
    {150*0.3048,  'ANSI_TP2', 'Node', '150 ft (46 m) ANSI_TP2->', 150*0.3048,   'ANSI_TP2', 'BT', '150 ft (46 m) ANSI_TP2->'},...
    {150*0.3048,  'ANSI_TP2', 'NT1', '150 ft (46 m) ANSI_TP2->', 0, '', '', ''}};
tt.traffic={...
    {1, 4 ,'VDSL', 25}};
ttlist=insertList(ttlist,tt);

tt.name= 'ANSI VDSL loop4 medium';             % T1E1.4 Loops
tt.topology={...
    {0,  '', 'CO', '', 0, '', '', ''},...
    {3000*0.3048,   'ANSI_TP1', 'Node', '3000 ft (914 m) ANSI_TP1->', 300*0.3048,   'ANSI_TP2', 'BT', '300 ft (91 m) ANSI_TP2->'},...
    {150*0.3048,   'ANSI_TP2', 'Node', '150 ft (46 m) ANSI_TP2->', 150*0.3048,   'ANSI_TP2', 'BT', '150 ft (46 m) ANSI_TP2->'},...
    {150*0.3048,  'ANSI_TP2', 'NT1', '150 ft (46 m) ANSI_TP2->', 0, '', '', ''}};
tt.traffic={...
    {1, 4, 'VDSL', 25}};
ttlist=insertList(ttlist,tt);

tt.name= 'ANSI VDSL loop4 long';             % T1E1.4 Loops
tt.topology={...
    {0,  '', 'CO', '', 0, '', '', ''},...
    {4500*0.3048,   'ANSI_TP1', 'Node', '4500 ft (1.37 km) ANSI_TP1->', 300*0.3048,   'ANSI_TP2', 'BT', '300 ft (91 m) ANSI_TP2->'},...
    {150*0.3048 ,  'ANSI_TP2', 'Node', '150 ft (46 m) ANSI_TP2->', 150*0.3048,  'ANSI_TP2', 'BT', '150 ft (46 m) ANSI_TP2->'},...
    {150*0.3048,  'ANSI_TP2', 'NT1', '150 ft (46 m) ANSI_TP2->', 0, '', '', ''}};
tt.traffic={...
    {1, 4, 'VDSL', 25}};
ttlist=insertList(ttlist,tt);



%-- ANSI VDSL loop 5 ----------------
% -----------------------------------
tt.name= 'ANSI VDSL loop5';             % T1E1.4 Loops
tt.topology={...
    {0,  '', 'CO', '', 0, '', '', ''},...
    {550*0.3048,   'ANSI_TP2', 'Node', '550 ft (167 m) ANSI_TP2->', 0, '', '', '' },...
    {100*0.3048,   'ANSI_TP2', 'Node', '100 ft (30 m) ANSI_TP2->', 0, '', '', '' },...
    {250*0.3048,   'ANSI_TP2', 'Node', '250 ft (76 m) ANSI_TP2->', 50*0.3048,   'ANSI_TP2', 'BT', '50 ft (15 m) ANSI_TP2->'},...
    {50*0.3048,  'ANSI_TP3', 'NT1', '50 ft (15 m) ANSI_TP3->', 0, '', '', ''}};
tt.traffic={...
    {1, 5, 'VDSL', 25}};
ttlist=insertList(ttlist,tt);


%-- ANSI VDSL loop 6 ----------------
% -----------------------------------
tt.name= 'ANSI VDSL loop6';             % T1E1.4 Loops
tt.topology={...
    {0,  '', 'CO', '', 0, '', '', ''},...
    {1650*0.3048,   'ANSI_TP1', 'Node', '1650 ft (503 m) ANSI_TP1->', 0, '', '', '' },...
    {650*0.3048,   'ANSI_TP2', 'Node', '650 ft (198 m) ANSI_TP2->', 0, '', '', '' },...
    {550*0.3048,   'ANSI_TP2', 'Node', '550 ft (167 m) ANSI_TP2->', 0, '', '', '' },...
    {100*0.3048,   'ANSI_TP2', 'Node', '100 ft (30 m) ANSI_TP2->', 0, '', '', '' },...
    {250*0.3048,   'ANSI_TP2', 'Node', '250 ft (76 m) ANSI_TP2->', 50*0.3048,   'ANSI_TP2', 'BT', '50 ft (15 m) ANSI_TP2->'},...
    {50*0.3048,  'ANSI_TP3', 'NT1', '50 ft (15 m) ANSI_TP3->', 0, '', '', ''}};
tt.traffic={...
    {1, 7, 'VDSL', 25}};
ttlist=insertList(ttlist,tt);


%-- ANSI VDSL loop 7 ----------------
% -----------------------------------
tt.name= 'ANSI VDSL loop7';             % T1E1.4 Loops
tt.topology={...
    {0,  '', 'CO', '', 0, '', '', ''},...
    {1650*0.3048,   'ANSI_TP1', 'Node', '1650 ft (503 m) ANSI_TP1->', 0, '', '', '' },...
    {2300*0.3048,   'ANSI_TP2', 'Node', '2300 ft (701 m) ANSI_TP2->', 0 ,'', '', '' },...
    {550*0.3048,   'ANSI_TP2', 'Node', '550 ft (167 m) ANSI_TP2->', 0, '', '', '' },...
    {100*0.3048,   'ANSI_TP2', 'Node', '100 ft (30 m) ANSI_TP2->' ,0, '', '', '' },...
    {250*0.3048,   'ANSI_TP2', 'Node', '250 ft (76 m) ANSI_TP2->', 50*0.3048,   'ANSI_TP2', 'BT', '50 ft (15 m) ANSI_TP2->'},...
    {50*0.3048,  'ANSI_TP3', 'NT1', '50 ft (15 m) ANSI_TP3->', 0, '', '', ''}};
tt.traffic={...
    {1, 7, 'VDSL', 25}};
ttlist=insertList(ttlist,tt);

