function [tfplist, hamBandName] = etsi_tfplanHAM(tfplist);
%% ===========================================================================
%etsi_tfplanHAM(tfplist) - Sets up the tfplan for ETSI HAM band
%
% Parameter:    tfplist	        Structure describing the time and freq plan
% Returns:      tfplist		Structure describing the time and freq plan
%
% Example(s):
%   ex.tfplist = etsi_tfplanHAM(ex.tfplist);    Add to existing tfplist
%   tfplan=getList(ex.tfplist,'ETSI-HAMBAND');  Get this HAM band
%
%   ex.tfplist = etsi_tfplanHAM([]);            Create a new tfplist
%   tfplan=getList(ex.tfplist,'ETSI-HAMBAND');  Get this HAM band
%
% Reference:
%   ETSI VDSL Part 1 TS 101-270-1 V1.1.6 (1999-08)  
%% ===========================================================================

%% ===========================================================================
% Copyright (C):
%       1999-2000 by Telia Research AB, Lulea, Sweden;
%       2000-2003 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: etsi_tfplanHAM.m,v 3.1 2002/12/27 15:48:08 tono Exp $
%% ===========================================================================
% Change History
%      1999-10-25 (ToNo) Created
%      1999-11-04 (ToNo) Made it into a function
%      2000-04-05 (UvAn) Added frequency axis for the call to calcPSD
%      2000-04-05 (UvAn) Removed ex struct and added tfplan.name as output
%      2002-08-23 (ToNo) Defined the template by calling a function
%% ===========================================================================

%% ===========================================================================
% Use a template, as order is important!

def_tfplan = templateTFP;


%% ===========================================================================
% TFPlan  definitions starting
% -------------------------------

% ETSI HAM bands
tmp_tfplan=def_tfplan;
tmp_tfplan.name='ETSI-HAMBAND';
tmp_tfplan.PSD.downstream='calcPSD([ 3e3 0 1.81e6 0 1.81e6 -80 2e6 -80 2e6 0 3.5e6 0 3.5e6 -80 3.8e6 -80 3.8e6 0 7e6 0 7e6 -80 7.1e6 -80 7.1e6 0 10.1e6 0 10.1e6 -80 10.15e6 -80 10.15e6 0 14e6 0 14e6 -80 14.35e6 -80 14.35e6 0 18.068e6 0 18.068e6 -80 18.168e6 -80 18.168e6 0 21e6 0 21e6 -80 21.45e6 -80 21.45e6 0 24.89e6 0 24.89e6 -80 24.99e6 -80 24.99e6 0 28e6 0 28e6 -80 29.1e6 -80 29.1e6 0],''Linear'',ex.param.frequency.f)';  
tmp_tfplan.PSD.upstream=tmp_tfplan.PSD.downstream;
tfplist=insertList(tfplist,tmp_tfplan);

hamBandName = tmp_tfplan.name;
