function tfplist = etsi_tfplansSDSL(tfplist);
%% ===========================================================================
% etsi_tfplansSDSL(tfplist) - Sets up the tfplan for ETSI SDSL
%
% Parameter:    tfplist	   Structure describing the time and freq plan
% Returns:      tfplist		Structure describing the time and freq plan
%
% Example(s):
%   ex.tfplist = etsi_tfplanSDSL(ex.tfplist);    Add to existing tfplist
%   tfplan=getList(ex.tfplist,'SDSL-sym') ;      Get this SDSL plan
%
%   ex.tfplist = etsi_tfplanSDSL([]);            Create a new tfplist
%   tfplan=getList(ex.tfplist,'SDSL-sym');       Get this SDSL plan
%
% References:	
%   Draft ETSI TS 101524-2 V1.1.1 (2000-05)
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       2000-2003 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.B.Nordstrom@Telia.se)
%               : Gernot Schmid (schmid@ftw.at)
%
% CVS:       $Id: etsi_tfplansSDSL.m,v 3.1 2002/12/27 15:48:08 tono Exp $
%% ===========================================================================
% Change History
%      2000-01-19 (GS) Created
%      2000-09-27 (GS) Cleaning up for release
%% ===========================================================================


%% ===========================================================================
% Use a template, as order is important!

sdsl_tfplan = templateTFP;
    
% SDSL generic default values
sdsl_tfplan.PSD.HAM.active        = 0;
sdsl_tfplan.PSD.active.upstream   = [5e3 2e6];
sdsl_tfplan.PSD.active.downstream = [5e3 2e6];
sdsl_tfplan.fixBitrate.name       = 'SDSL';
sdsl_tfplan.fixBitrate.active     = 1;
sdsl_tfplan.fixBitrate.param      = 'N/A';


% SDSL TFPlan defintions
% --------------------------

% symmetric SDSL as specified in	Draft ETSI TS 101524-2 V1.1.1 (2000-05)
tmp_tfplan=sdsl_tfplan;
tmp_tfplan.name='SDSL-sym';
tmp_tfplan.lcname='SDSL-sym';
tmp_tfplan.PSD.downstream ='modelPSD_SDSL_sym(tfplan.lcname,ex.param.frequency.f)'; 
tmp_tfplan.PSD.upstream   = tmp_tfplan.PSD.downstream;	
tmp_tfplan.PSD.PBO.method='None'; 
tfplist=insertList(tfplist,tmp_tfplan);

% 	asymmetric SDSL as specified in Draft ETSI TS 101524-2 V1.1.1 (2000-05)
tmp_tfplan=sdsl_tfplan;
tmp_tfplan.name='SDSL-asym';
tmp_tfplan.lcname='SDSL-asym';
tmp_tfplan.PSD.downstream ='modelPSD_SDSL_asym(tfplan.lcname,ex.param.frequency.f,1)'; 
tmp_tfplan.PSD.upstream   ='modelPSD_SDSL_asym(tfplan.lcname,ex.param.frequency.f,2)';
tmp_tfplan.PSD.PBO.method='None'; 
tfplist=insertList(tfplist,tmp_tfplan);
