function clist = itu_cablesADSL(clist);
%% ===========================================================================
%itu_cablesADSL(clist) - Sets up the cable models for ETSI
%
% Parameter:    clist          Structure describing the cables
% Returns:      clist          Structure describing the cables
%
% Example(s):
%   ex.clist   = itu_cablesADSL(ex.clist);               % Add to existing clist
%   cableparam = getList(ex.clist,'ITU-ADSL-PE032'); % Get ETSI PE 0.32 cable
%
% Reference:
%   ITU G.996.1 (Draft)
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       2000-2003 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: itu_cablesADSL.m,v 3.2 2003/04/22 13:45:20 tono Exp $
%% ===========================================================================
% Change History
%      2000-09-09 (ToNo) Created to support G.996.1
%      2002-03-18 (ToNo) Switched to parametric model instead of the tables
%% ===========================================================================

% Use the definitions of the ITU cables in the ETSI standard definitions    

if length(clist)    == 0
    clist = etsi_cablesADSL([]);
end;

% Note that this is using the old values in ITU 996.1, while the
% ETSI values are updated (cf. etsi_cablesADSL)!

cable=getList(clist,'ETSI-ADSL-PE032i');

if length(cable)    == 0
    fprintf('Warning: itu_cablesADSL depend on etsi_cablesADSL_extra\n');
    clist =  etsi_cablesADSL_extra(clist);
    cable=getList(clist,'ETSI-ADSL-PE032i');
end;

cable.name='ITU-ADSL-PE032';
clist=insertList(clist,cable);
    
cable=getList(clist,'ETSI-ADSL-PE04i');
cable.name='ITU-ADSL-PE04';
clist=insertList(clist,cable);
    
cable=getList(clist,'ETSI-ADSL-PE05i');
cable.name='ITU-ADSL-PE05';
clist=insertList(clist,cable);
    
cable=getList(clist,'ETSI-ADSL-PE063i');
cable.name='ITU-ADSL-PE063';
clist=insertList(clist,cable);

cable=getList(clist,'ETSI-ADSL-PE09i');
cable.name='ITU-ADSL-PE09';
clist=insertList(clist,cable);
    

%% ===========================================================================
% ITU (ANSI) cables

% TP2 0.5 mm 24-AWG 
cable=[];
cable.name='ITU-ADSL-24AWG';
cable.model='BT';
cable.param.r0c=174.559;
cable.param.r0s=0;
cable.param.ac=0.05307;
cable.param.as=0.0;
cable.param.l0=617.295e-6;
cable.param.loo=478.971e-6;
cable.param.b=1.15298;
cable.param.fm=553.760e3;
cable.param.coo=50e-9;
cable.param.c0=0;
cable.param.ce=0;
cable.param.g0=0;
cable.param.ge=1;
clist=insertList(clist,cable);

% TP1 0.4 mm 26-AWG 
cable=[];
cable.name='ITU-ADSL-26AWG';
cable.model='BT';
cable.param.r0c=286.176;
cable.param.r0s=0;
cable.param.ac=0.14769620;
cable.param.as=0.0;
cable.param.l0=675.369e-6;
cable.param.loo=488.952e-6;
cable.param.b=0.929;
cable.param.fm=806.339e3;
cable.param.coo=49e-9;
cable.param.c0=0;
cable.param.ce=0;
cable.param.g0=0;
cable.param.ge=1;
clist=insertList(clist,cable);

