function lc = lcDefSDSL_asym;
%% ===========================================================================
% lcDefSDSL_asym - Sets up the lincode description structure for 
%                  asymmetric SDSL  
%
% Returns:       lc	The linecode structure
%
% References:	
%    Draft ETSI TS 101524-2 V1.1.1 (2000-05)
%    Chen W., "DSL simulation techniques and standards development
%    for DSL systems"
%    Starr T., J. Cioffi, P. Silverman "Understanding DSL technology", 1999
%    The xDSL simulation tool manual, FTW 2000
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 2000-2003 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                     All rights reserved. 
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Gernot Schmid (schmid@ftw.at
%% ===========================================================================
% Change History
%      2000-03-30 (GS)   Created
%      2000-04-12 (GS)   Receive filter extensions
%      2000-09-27 (GS)   Cleaning up for release
%      2003-12-16 (ToNo) Split background noise into bgNoise and modemNoise
%      2003-12-17 (ToNo) Changed default to include a xtalk_margin of 6 dB
%% ===========================================================================

lc.name                   = 'SDSL-asym';

% Default Parameter values

lc.param.Px.up  = [0 2048e3 2304e3 1e99; 13.5 16.5 15.25 15.25;]; % TX power templates
lc.param.Px.dn	= [0 2048e3 2304e3 1e99; 13.5 16.25 14.75 14.75;];% TX power templates
lc.param.signal_margin    = 0;
lc.param.codingGain       = 5.1;  
lc.param.xtalk_margin     = 6;
lc.param.refSNR           = 9.8;
lc.param.SNRloss          = 1.6;      % 1.6; 2.1 for loop 6 (with bridge taps
lc.param.constellation    = 4;        % 16 PA

% Calculate the req SNR [Starr]:
% M  = 2^(lc.param.constellation-1);  % UC coding reduces the size by one
% Pe = 1e-7;
% ei = erfinv(1-Pe/(1-1/M));
% lc.param.reqSNR           = 10*log10((M*M-1)*2/3*ei^2);
lc.param.reqSNR           = 27.71; % [Chen p 524] or [ETSI 994t40a0]

% Param digital
lc.param.pam.bpsym        = lc.param.constellation-1; % Bits per symbol 
lc.param.pam.brate.rate   = 512e3; % Bitrate in bit per sec. (excl. overhead)
lc.param.pam.brate.ohead  = 8e3;   % Datarate overhead
lc.param.pam.filterorder.up =[0 2048e3 2304e3 1e99; 6 7 7 7;]; % filter order template 
lc.param.pam.filterorder.dn =[0 2048e3 2304e3 1e99; 6 7 7 7;]; % filter order template
lc.param.pam.filterratio  = 0.5;   % f3dB/fsym ratio  
%fx generated temporary in 'modelPSD_SDSL_asym.m' 

lc.param.pam.k.up	  = [0 2048e3 2304e3 1e99; 7.86 15.66 11.74 11.74;]; % scaling factor template
lc.param.pam.k.dn	  = [0 2048e3 2304e3 1e99; 7.86 8.43 6.24 6.24;]; % scaling factor template

lc.param.pam.highpass3dBf = 5e3; % Coupling transformer cutoff frequency    

% Optional receive filter 
lc.param.pam.recfilterorder.up=[0 2048e3 2304e3 1e99; 6 7 7 7;]; 
lc.param.pam.recfilterorder.dn=[0 2048e3 2304e3 1e99; 6 7 7 7;]; 
% Receive filter 3dB frequencies defined in 'modelPSD_SDSL_asym.m'

lc.param.SNRMax           = 100;    % Maximum SNR usable [Chen p.524]
lc.param.efficiencyLoss   = 0;      % General efficiency loss factor
                                    % SDSL uses SNRloss instead

lc.param.modemNoise.LT    = '-140'; % Modem noise at LT (dBm/Hz)
lc.param.modemNoise.NT    = '-140'; % Modem noise at NT (dBm/Hz)

lc.calcRate 		  = 'calcResultSDSL';
lc.lcPrint 		  = 'lcPrintSDSL';
