function P=modelPSD_ISDN_PRA(f)
%% ===========================================================================
% modelPSD_ISDN_PRA - calculates PSD mask for DTAG ISDN_PRA (HDB3) model 
%
% Parameter:    f	frequency axis
% Returns:      P	PSD mask  (in mW)
%
% Example(s):
%   
% Algorithmic details:
%   
% Reference:
%    FTW's xDSLsimu manual
%    Model provided by DTAG (ref. Mathias Friese)
%    TD20 ETSI Villach 1999    
%    TD22 ETSI Edinburgh 1999    
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1998-2000 by Telia Research AB, Lulea, Sweden;                
%       2000-2003 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%               : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Bo Engstrom (bosse@upzide.com)
%
% CVS:       $Id: modelPSD_ISDN_PRA.m,v 3.2 2003/11/30 20:10:04 tono Exp $
%% ===========================================================================
% Change History
%      1999-02-09 (DaB)  Created
%      1999-03-01 (DaB)  Use Rob's model from TD20 ETSI Villach 1999
%      2000-07-12 (ToNo) Moved to xdsldefs and cleaned up comments
%      2001-06-19 (Bosse) Octave port
%      2003-11-30 (ToNo) Removed internal sinc function
%% ===========================================================================

P0   = 12.4; % mW  = 10.92 dBm;  
Rs   = 130;   
f0   = 1.024.*1e6; 
f3dB = 1.024.*1e6; 
N    = 0.9;

P=2./f0.*(sinc(f./f0-1)).^2./(1 + (f/f3dB).^(2.*N)).*P0;
