function P=modelPSD_T1(f)
%% ===========================================================================
% modelPSD_T1 PSD mask for T1
%
% Parameter:    f	frequency axis
% Returns:      P	PSD mask (in mW)
%
% Example(s):
%   
% Algorithmic details:
%   
% Reference:
%    T1E1.4/99 -438R2
%% ===========================================================================

%% ===========================================================================
% Copyright (C) 2000-2003 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                     All rights reserved. 
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%
% CVS:       $Id: modelPSD_T1.m,v 3.2 2003/11/30 20:10:04 tono Exp $
%% ===========================================================================
% Change History
%      2000-07-10 (ToNo) Created
%      2003-11-30 (ToNo) Removed internal sinc function
%% ===========================================================================

Vp    = 3.6;    % V
R     = 100;    % Ohm
f0    = 1544e3; % Hz
fL3dB = 3e6;    % Hz
fH3dB = 40e3;   % Hz

P=(Vp*Vp/R)*(2/f0)*(sinc(f/f0)).^2.*(sin(pi*f/2/f0)).^2 ...
  ./(1 + (f/fL3dB).^6).*f.^2./(f.^2+fH3dB.^2) * 1000; % mW
