function tfplist = special_modelsVDSL(tfplist);
%% ===========================================================================
%special_modelsVDSL(tfplist) - Sets up the tfplan for fsan VDSL tests
%
% Parameter:    tfplist	        Structure describing the time and freq plan
% Returns:      tfplist		Structure describing the time and freq plan
%
% Example(s):
%   ex.tfplist = fsan_tfplanVDSL(ex.tfplist);    Add to existing tfplist
%   tfplan=getList(ex.tfplist,'VDSL-test') ;     Get this VDSL plan
%
%   ex.tfplist = fsan_tfplanVDSL([]);            Create a new tfplist
%   tfplan=getList(ex.tfplist,'VDSL-test');      Get this VDSL plan
%
% Reference:
%    FTW's xDSLsimu manual
%% ===========================================================================

%% ===========================================================================
% Copyright (C):
%       1999-2000 by Telia Research AB, Lulea, Sweden;
%       2000-2003 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FTW's xDSLsimu
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: special_modelsVDSL.m,v 3.2 2003/03/07 16:52:23 tono Exp $
%% ===========================================================================
% Change History
%      1999-11-04 (ToNo) Created
%      2000-04-05 (UvAn) Added frequency axis for the call to calcPSD
%      2000-04-11 (DaB)  Added sync
%      2000-05-26 (UvAn) Added possibillities to fix the bitrate 
%      2003-01-02 (ToNo) Changed defailt vaules
%% ===========================================================================

% Default values
def_tfplan = templateTFP;

% VDSL TFPlan defintions
% --------------------------
% VDSL Test
tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL-test';
tmp_tfplan.PSD.downstream ='calcPSD([.3e6 -120 .3e6 -60 3.5e6 -60 3.5e6 -120],''Linear'',ex.param.frequency.f)'; 
tmp_tfplan.PSD.upstream   ='calcPSD([3.5e6 -120 3.5e6 -60 11.04e6 -60 11.04e6 -120],''Linear'',ex.param.frequency.f)';	
tmp_tfplan.PSD.PBO.method='None';	% Power back-off method 
tmp_tfplan.lcname='VDSL-theo';
tfplist=insertList(tfplist,tmp_tfplan);

% VDSL Full Spectra (TDD)
tmp_tfplan=def_tfplan;
tmp_tfplan.name='VDSL-fullspectra';
tmp_tfplan.PSD.downstream ='calcPSD([1e3 -120 1e3 -60 12e6 -60 12e6 -120],''Linear'',ex.param.frequency.f)'; 
tmp_tfplan.PSD.upstream   = tmp_tfplan.PSD.downstream;	
tmp_tfplan.PSD.PBO.method='None';	% Power back-off method
tmp_tfplan.timeDivision.up       = 0.5;
tmp_tfplan.timeDivision.down     = 0.5;
tmp_tfplan.lcname='VDSL-theo';
tfplist=insertList(tfplist,tmp_tfplan);

